package
Version:
v0.10.6
Opens a new window with list of versions in this module.
Published: Sep 12, 2026
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package debugtime provides opt-in wall-clock timings without a metrics subsystem.
Logf writes a diagnostic line to stderr when LIVE_PR_DEBUG_TIMING is enabled.
Use it where an error is otherwise swallowed for UX reasons.
func Start(name string) func()
Start returns a completion logger when LIVE_PR_DEBUG_TIMING is enabled.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.